import { mapStateToControlProps, rankWith } from '@jsonforms/core';
import { html } from '@microsoft/fast-element';
import { GenesisType } from '../../utils';
import { isOneOfDate } from '../testers/isDate';
import { DATE_CONTROL_RANK } from './RenderersRanks';
/**
 * @internal
 */
const typeSwitch = (control) => { var _a; return ((_a = control.schema) === null || _a === void 0 ? void 0 : _a.genesisType) === GenesisType.DATETIME ? 'datetime-local' : 'date'; };
export const DateControlRendererTemplate = (prefix = 'zero') => html `
  <template>
    <control-wrapper
      :control=${(x) => x.control}
      :touched=${(x) => x.touched}
      ?submitted=${(x) => x.submitted}
    >
      <${prefix}-text-field
        :value=${(x) => {
    const type = typeSwitch(x.control);
    const formats = {
        year: 'numeric',
        month: '2-digit',
        day: '2-digit',
        timeZone: 'UTC',
    };
    if (type === 'datetime-local') {
        formats.hour = '2-digit:'; // need the : otherwise the format is invalid
        formats.minute = '2-digit';
    }
    return x.control.data === undefined || x.control.data === null
        ? ''
        : new Intl.DateTimeFormat('fr-CA', formats).format(x.control.data);
}}
        id=${(x) => x.control.path}
        type="${(x) => typeSwitch(x.control)}"
        data-test-id=${(x) => x.control.path}
        ?required=${(x) => x.control.required}
        ?disabled=${(x) => !x.control.enabled}
        @blur=${(x, c) => {
    const dateValue = c.event.target.control.valueAsNumber;
    x.onBlur();
    x.control.handleChange(x.control.path, !isNaN(dateValue) ? dateValue : undefined);
}}"
        style="width: 100%"
      ></${prefix}-text-field>
    </control-wrapper>
  </template>
`;
export const DateControlRendererEntry = {
    renderer: html `
    ${(x) => DateControlRendererTemplate(x.prefix)}
  `,
    tester: rankWith(DATE_CONTROL_RANK, isOneOfDate),
    mapper: mapStateToControlProps, // TODO: change mapper to handle dates instead of doing it in the template
};
